# Sage version information for Python scripts
# This file is auto-generated by the sage-update-version script, do not edit!
version = '10.6.rc1'
date = '2025-03-27'
banner = 'SageMath version 10.6.rc1, Release Date: 2025-03-27'
